@@ -104,11 +104,9 @@ func generateNode(node *parser.Node) (Criteria, error) {
 
 func generateLeaf(leaf *parser.Leaf) (Criteria, error) {
 	needEscape := leaf.Function != parser.FunctionQuery && !leaf.IsRaw
-	query, err := joinStrings(needEscape, leaf.Args...)
-	if err != nil {
-		return Criteria{}, err
-	}
+	query := joinStrings(needEscape, leaf.Args...)
 	if len(leaf.Args) > 1 {
+		var err error
 		if query, err = groupWithOperation(query, leaf.Grouping); err != nil {
 			return Criteria{}, err
 		}
@@ -176,11 +174,9 @@ func generateNodeAsString(node *parser.Node) (string, error) {
 
 func generateLeafAsString(leaf *parser.Leaf) (string, error) {
 	needEscape := leaf.Function != parser.FunctionQuery && !leaf.IsRaw
-	query, err := joinStrings(needEscape, leaf.Args...)
-	if err != nil {
-		return "", err
-	}
+	query := joinStrings(needEscape, leaf.Args...)
 	if len(leaf.Args) > 1 {
+		var err error
 		if query, err = groupWithOperation(query, leaf.Grouping); err != nil {
 			return "", err
 		}
@@ -230,34 +226,35 @@ func joinQueries(f1, f2 string) string {
 	return fmt.Sprintf("%s %s", f1, f2)
 }
 
-func joinStrings(escape bool, a ...string) (string, error) {
+func joinStrings(escape bool, a ...string) string {
 	if escape {
-		for _, a := range a {
-			if strings.Contains(a, `"`) {
-				return "", fmt.Errorf("invalid quote in %q", a)
-			}
-		}
-		return joinEscaped(a...), nil
+		return joinQuoted(a...)
 	}
-	return strings.Join(a, " "), nil
+	return strings.Join(a, " ")
 }
 
-func joinEscaped(a ...string) string {
-	return strings.Join(escapeStrings(a...), " ")
+func joinQuoted(a ...string) string {
+	return strings.Join(quoteStrings(a...), " ")
 }
 
-func escapeStrings(a ...string) []string {
+func quoteStrings(a ...string) []string {
 	res := make([]string, len(a))
 	for i, s := range a {
-		res[i] = escape(s)
+		res[i] = quote(s)
 	}
 	return res
 }
 
-func escape(a string) string {
+func quote(a string) string {
 	if strings.ContainsAny(a, " \t{}()") {
 		return fmt.Sprintf(`"%s"`, a)
 	}
+	// We need to quote the plus sign, _unless_ it's within a full email
+	// address. This is necessary because "foo+bar" is considered like
+	// "foo OR bar", but "foo+bar@gmail.com" is not.
+	if strings.Contains(a, "+") && !strings.Contains(a, "@") {
+		return fmt.Sprintf(`"%s"`, a)
+	}
 	return a
 }
 
@@ -457,7 +454,7 @@ func generateActions(actions parser.Actions) ([]Actions, error) {
 	}
 
 	if fromOptionalBool(actions.MarkSpam, true) {
-		return nil, errors.New("Gmail filters don't allow one to send messages to spam directly")
+		return nil, errors.New("gmail filters don't allow one to send messages to spam directly")
 	}
 
 	if len(actions.Labels) == 0 {
