@@ -13,23 +13,29 @@ func boolptr(a bool) *bool {
 	return &a
 }
 
-func TestSimpleFilter(t *testing.T) {
+func TestQuotes(t *testing.T) {
 	rules := []parser.Rule{
 		{
 			Criteria: &parser.Leaf{
 				Function: parser.FunctionFrom,
 				Grouping: parser.OperationOr,
-				Args:     []string{"a", "b", "with spaces"},
+				Args: []string{
+					"a",
+					"with spaces",
+					"with+plus",
+					"with+plus@email.com",
+				},
 			},
 			Actions: parser.Actions{
 				Archive: true,
 			},
 		},
 	}
+	// The plus sign is quoted, except for when in full email addresses.
 	expected := Filters{
 		{
 			Criteria: Criteria{
-				From: `{a b "with spaces"}`,
+				From: `{a "with spaces" "with+plus" with+plus@email.com}`,
 			},
 			Action: Actions{
 				Archive: true,
@@ -363,21 +369,3 @@ func TestActions(t *testing.T) {
 	assert.Nil(t, err)
 	assert.Equal(t, expected, got)
 }
-
-func TestDoubleQuoteError(t *testing.T) {
-	rules := []parser.Rule{
-		{
-			Criteria: &parser.Leaf{
-				Function: parser.FunctionSubject,
-				Args:     []string{`a"b`},
-				IsRaw:    false,
-			},
-			Actions: parser.Actions{
-				// action choice is irrelevant
-				Labels: []string{"l1"},
-			},
-		},
-	}
-	_, err := FromRules(rules)
-	assert.ErrorContains(t, err, "invalid quote")
-}
